.. _catalogs:

************************************
Classes to manage Catalogs and WCS's
************************************

This module provides the classes used to generate and manage source catalogs
for each input chip. Those positions can be transformed to undistorted sky
positions, written out to files, or plotted using various methods defined
for these classes.

.. moduleauthor:: Warren Hack <help@stsci.edu>

.. currentmodule:: drizzlepac.catalogs

.. automodule:: drizzlepac.catalogs

.. inheritance-diagram:: drizzlepac.catalogs
   :parts: 2

.. autofunction:: generateCatalog

.. autoclass:: ImageCatalog
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: UserCatalog
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: RefCatalog
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: Catalog
   :members:
   :undoc-members:
   :show-inheritance:



